class GuidepostsController < ApplicationController
  before_action :set_guidepost, only: [:show, :edit, :update, :destroy]
  before_action :ensure_admin!, except: [:show, :index]

  def index
    @guideposts = Guidepost.all
    # filtry
    @guideposts = @guideposts.where('lat IS NOT NULL AND  lon IS NOT NULL') if filter_set? 'with_position'
    @guideposts = @guideposts.where(id: Photo.select(:guidepost_id)) if filter_set? 'with_photo'
    @guideposts = @guideposts.where('LEFT(kctref,2) = ?', params[:region]) unless params[:region].blank?
    @guideposts = @guideposts.search(params[:search]) unless params[:search].blank?
    
    # paginace
    @guideposts = @guideposts.page(params[:page])
  end

  def status_index
    @guideposts = Guidepost.where("kctref LIKE 'PJ___'",)  #  Guideposts.with(params)
  end

  def show
    @kct_guidepost = KctGuidepost.find_by_kctref(@guidepost.kctref)
    @osm_guidepost = OsmGuidepost.find_by_osmid(@guidepost.osmid)
    if @osm_guidepost.nil?
      @osm_guidepost_candidates = @guidepost.osm_guideposts_nearby(2000)
    end
  end

  def new
    @guidepost = Guidepost.new(guidepost_params)
    # kctref: params[:kctref], osmid: params[:osmid], lat: params[:lat], lon: params[:lon], nazev: params[:nazev]
    create if params[:doit]
  end

  def edit
    @guidepost.assign_attributes(guidepost_params) if guidepost_params
    update if params[:doit]
  end

  # POST /guideposts
  # POST /guideposts.json
  def create
    if guidepost_params[:kct_guidepost]
      kct_guidepost = KctGuidepost.find(params[:kct_guidepost])      
      raise "Rozcestník s kctref #{kct_guidepost.kctref} již existuje. Not creating." if Guidepost.find_by_kctref(kct_guidepost.kctref)      
      @guidepost = Guidepost.new_from_kct_guidepost(kct_guidepost)
    elsif guidepost_params[:kctref]
      raise "Rozcestník s kctref #{guidepost_params[:kctref]} již existuje. Not creating." if Guidepost.find_by_kctref(guidepost_params[:kctref])
      @guidepost = Guidepost.new(guidepost_params)
    elsif guidepost_params[:osmid]
      raise "Rozcestník s osmid #{guidepost_params[:osmid]} již existuje. Not creating." if Guidepost.find_by_osmid(guidepost_params[:osmid])
      @guidepost = Guidepost.new(guidepost_params)
    else
      @guidepost = Guidepost.new(guidepost_params)
    end
    
    @guidepost.copy_coordinates_from_osm_if_needed

    respond_to do |format|
      if @guidepost.save
        format.html { redirect_to @guidepost, notice: 'Guidepost was successfully created.' }
        format.json { render action: 'show', status: :created, location: @guidepost }
      else
        format.html { render action: 'new' }
        format.json { render json: "Nepodařilo se rozc. vytvořit(#{@guidepost.errors})", status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /guideposts/1
  # PATCH/PUT /guideposts/1.json
  def update
    respond_to do |format|
      if @guidepost.update(guidepost_params)
        format.html { redirect_to @guidepost, notice: 'Guidepost was successfully updated.' }
        format.json { head :no_content }
      else
        format.html { render action: 'edit' }
        format.json { render json: @guidepost.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /guideposts/1
  # DELETE /guideposts/1.json
  def destroy
    @guidepost.destroy
    respond_to do |format|
      format.html { redirect_to guideposts_url }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_guidepost
      begin
        if params[:id].match /kctref-(.*)/  # umožňuje použíte kctref-XXXX místo id v databázi
          @guidepost = Guidepost.find_by_kctref($1)
        else
          @guidepost = Guidepost.find(params[:id])
        end
      rescue ActiveRecord::RecordNotFound
        flash.alert = "Tento guidepost není v databázi. Možná jde o starý odkaz a mezitím byla databáze reimportována."
        redirect_to :action=> :index
      end
    end

    

    # Never trust parameters from the scary internet, only allow the white list through.
    def guidepost_params
      params[:guidepost].andand.permit(:nazev, :kctref, :ele, :lat, :lon, :osmid, :nazev_short, :sez_guidepost_id, :pozn)
    end
end
